This function returns the cram policy estimator for the policy value difference (delta).
cram_estimator(X, Y, D, pi, batch_indices, propensity = NULL)The estimated policy value difference (Delta).
A matrix or data frame of covariates for each sample.
A vector of outcomes for the n individuals.
A vector of binary treatments for the n individuals.
A matrix of n rows and (nb_batch + 1) columns, where n is the sample size and nb_batch is the number of batches, containing the policy assignment for each individual for each policy. The first column represents the baseline policy.
A list where each element is a vector of indices corresponding to the individuals in each batch.
The propensity score function