This function computes the Cram ML expected loss estimator based on the given loss matrix and batch indices.
cram_expected_loss(loss, batch_indices)The Cram ML expected loss estimate
A matrix of loss values with N rows (data points) and K+1 columns (batches). We assume that the first column of the loss matrix contains only zeros. The following nb_batch columns contain the losses of each trained model for each individual.
A list where each element is a vector of indices corresponding to a batch.