This function estimates the asymptotic variance of the cram estimator for the policy value (psi).
cram_variance_estimator_policy_value(
X,
Y,
D,
pi,
batch_indices,
propensity = NULL
)The variance estimate of the crammed Policy Value estimate (Psi)
A matrix or data frame of covariates for each sample.
A vector of outcomes for the n individuals.
A vector of binary treatments for the n individuals.
A matrix of n rows and (nb_batch + 1) columns, where n is the sample size and nb_batch is the number of batches, containing the policy assignment for each individual for each policy. The first column represents the baseline policy.
A list where each element is a vector of indices corresponding to the individuals in each batch.
Propensity score function