Learn R Programming

cramR (version 0.1.1)

fit_model_ml: Cram ML: Fit Model ML

Description

This function trains a given unfitted model with the provided data and parameters, according to model type and learner type.

Usage

fit_model_ml(data, formula, caret_params, classify)

Value

The fitted model object.

Arguments

data

The dataset

formula

The formula

caret_params

The parameters for caret model

classify

Indicate if this is a classification problem. Defaults to FALSE