Creates a list of matrices representing the arm-specific reward-generating parameters (betas) used in contextual linear bandit simulations. Each matrix corresponds to one simulation and contains normalized random coefficients.
get_betas(simulations, d, k)A list of length simulations + 1 (first element being discarded in the underlying
simulation package), each containing a d x k matrix of normalized reward parameters.
Integer. Number of simulations.
Integer. Number of features (context dimensions).
Integer. Number of arms.