Learn R Programming

cramR (version 0.1.1)

test_baseline_policy: Validate or Set the Baseline Policy

Description

This function validates a provided baseline policy or sets a default baseline policy of zeros for all individuals.

Usage

test_baseline_policy(baseline_policy, n)

Value

A validated or default baseline policy as a list of numeric values.

Arguments

baseline_policy

A list representing the baseline policy for each individual. If NULL, a default baseline policy of zeros is created.

n

An integer specifying the number of individuals in the population.